@@ -51,7 +51,7 @@ from sqlalchemy.testing import engines
 from sqlalchemy.testing import eq_
 from sqlalchemy.testing import fixtures
 from sqlalchemy.testing import is_
-from sqlalchemy.testing import is_not_
+from sqlalchemy.testing import is_not
 from sqlalchemy.testing import pickleable
 from sqlalchemy.util import b
 
@@ -789,7 +789,9 @@ class TypeRoundTripTest(
     @testing.metadata_fixture()
     def datetimeoffset_fixture(self, metadata):
         t = Table(
-            "test_dates", metadata, Column("adatetimeoffset", DATETIMEOFFSET),
+            "test_dates",
+            metadata,
+            Column("adatetimeoffset", DATETIMEOFFSET),
         )
 
         return t
@@ -886,7 +888,8 @@ class TypeRoundTripTest(
                 return
 
             conn.execute(
-                t.insert(), adatetimeoffset=dto_param_value,
+                t.insert(),
+                adatetimeoffset=dto_param_value,
             )
 
             row = conn.execute(t.select()).first()
@@ -1051,7 +1054,7 @@ class TypeRoundTripTest(
                     is_(tbl._autoincrement_column, col)
                 else:
                     eq_(col.autoincrement, "auto")
-                    is_not_(tbl._autoincrement_column, col)
+                    is_not(tbl._autoincrement_column, col)
 
             # mxodbc can't handle scope_identity() with DEFAULT VALUES
 
